## host definition file - where you specify the physical configuration for all of your various host types
## role: the type of 'thing' it is, currently used options are controller, compute, storage, and container.
## macs: python list of all the macs belonging to this type of host
## interface: the interface that you want to use when PXE booting (should be DHCP enabled)
## proxy: if you have a static, external proxy, place the address here.  Otherwise use pull_from_mine to use the internal one
## root_password: preseeded password.  See mkpasswd.
## ntp_server: the ntp server that you want to use for the preseed process
## disk:  the disk you want to install the OS on to
## ipmi_addresses: the addresses for the IPMI interfaces on these devices

## kvm_disk_config - CONTROLLER ONLY
## type: raidX, where X is 1 or 10.  raid1 must have 2 members entries in the list.  raid10 must have a multiple of 2 members in the list
## type: standard.  May pass a device (e.g. /dev/sdb) as a single member, or pass the special value 'rootfs' as a single member, which will
## just create a directory on the root filesystem at /kvm

## networks: specify how you want your final, post-deployment network to be configured.
##   interface entries: top level definition will be the name of the physical interface
##     managed: whether or not the builtin networking state should manage the configuration.  boolean, defaults to True
##     interfaces: list of interfaces that will bind to the network.  If the list is <1, it implies a bond.
##     bridge: true if a bridged interface, otherwise false or omitted (implicit false)
##     rx_buffer: value is hardware dependent (see ethtool -g <nic> for max params). values range from 512 to 8192
##     tx_buffer: value is hardware dependent (see ethtool -g <nic> for max params). values range from 512 to 8192

hosts:
  controllerv1:
    style: physical
    role: controller
    enabled: False
    os: ubuntu2004
    uuids:
      - 00000000-0000-0000-0000-0CC47AFBEA30
      - 00000000-0000-0000-0000-0CC47AFBEB88
      - 00000000-0000-0000-0000-0CC47AFBEBB0
      - 00000000-0000-0000-0000-0CC47AFBEB80
      - 00000000-0000-0000-0000-0CC47AFBEBB8
      - 00000000-0000-0000-0000-0CC47AFBEB7C
    interface: enp97s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: Micron_9200_MTFDHAL6T4TCU
    kvm_disk_config:
      type: standard
      members:
        - rootfs
    networks:
      management:
        interfaces: [enp97s0f0]
        bridge: true
        rx_buffer: 8192
        tx_buffer: 8192
      sfe:
        interfaces: [enp113s0f0]
        bridge: true
        rx_buffer: 8192
        tx_buffer: 8192
      public:
        interfaces: [enp97s0f1]
        bridge: true
        rx_buffer: 8192
        tx_buffer: 8192
      private:
        interfaces: [enp113s0f1]
        bridge: true
        rx_buffer: 8192
        tx_buffer: 8192
  controllerv2:
    style: physical
    role: controller
    enabled: False
    os: ubuntu2004
    uuids:
      - 00000000-0000-0000-0000-AC1F6BC3B5D8
      - 00000000-0000-0000-0000-AC1F6BC3B5E8
      - 00000000-0000-0000-0000-AC1F6BC3B2E8
      - 00000000-0000-0000-0000-AC1F6BC3B2D4
#      - 00000000-0000-0000-0000-AC1F6BC3B590 ###-RMA-Won't Power On-###
      - 00000000-0000-0000-0000-AC1F6BC3B5F0
    interface: enp129s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: SAMSUNG MZWLL6T4HMLA
    kvm_disk_config:
      type: standard
      members:
        - rootfs
    networks:
      management:
        interfaces: [enp129s0f0]
        bridge: true
        rx_buffer: 4096
        tx_buffer: 4096
      sfe:
        interfaces: [enp129s0f1]
        bridge: true
        rx_buffer: 4096
        tx_buffer: 4096
      public:
        interfaces: [enp193s0f0]
        bridge: true
        rx_buffer: 4096
        tx_buffer: 4096
      private:
        interfaces: [enp193s0f1]
        bridge: true
        rx_buffer: 4096
        tx_buffer: 4096
  storagev1:
    style: physical
    role: storage
    enabled: False
    os: ubuntu2004
    uuids:
      - 00000000-0000-0000-0000-AC1F6B4E3500
      - 00000000-0000-0000-0000-AC1F6B4DAED4
      - 00000000-0000-0000-0000-AC1F6B4DAFAC
      - 00000000-0000-0000-0000-AC1F6B4E34EC
      - 00000000-0000-0000-0000-AC1F6B4E3484
      - 00000000-0000-0000-0000-AC1F6B4E34E6
      - 00000000-0000-0000-0000-AC1F6B4EA0CE
      - 00000000-0000-0000-0000-AC1F6B4DAF54
      - 00000000-0000-0000-0000-AC1F6B4E34EE
      - 00000000-0000-0000-0000-AC1F6B4E34E0
      - 00000000-0000-0000-0000-AC1F6B4DAEDC
      - 00000000-0000-0000-0000-AC1F6B4E352C
    interface: ens2f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: INTEL SSDPED1K750GA
    networks:
      management:
        interfaces: [ens2f0]
        rx_buffer: 8192
        tx_buffer: 8192
      sfe:
        interfaces: [ens2f1]
        rx_buffer: 8192
        tx_buffer: 8192
      sbe:
        interfaces: [ens1f0]
        rx_buffer: 8192
        tx_buffer: 8192
  storagev2:
    style: physical
    role: storage
    enabled: False
    os: ubuntu2004
    uuids:
      - 00000000-0000-0000-0000-AC1F6B4DAEFC
      - 00000000-0000-0000-0000-AC1F6B4E34E4
      - 00000000-0000-0000-0000-AC1F6B4E34E8
      - 00000000-0000-0000-0000-AC1F6B4DAF0C
      - 00000000-0000-0000-0000-AC1F6B4DAF46
      - 00000000-0000-0000-0000-AC1F6B4DAF44
      - 00000000-0000-0000-0000-AC1F6B4DAF68
      - 00000000-0000-0000-0000-AC1F6B4EA15A
#      - 00000000-0000-0000-0000-AC1F6B4DAED0 ###- won't power on -###
      - 00000000-0000-0000-0000-AC1F6B4DAF34
      - 00000000-0000-0000-0000-AC1F6B4E34EA
      - 00000000-0000-0000-0000-AC1F6BCC5364
    interface: ens2f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: INTEL SSDPED1K750GA
    networks:
      management:
        interfaces: [ens2f0]
        rx_buffer: 8192
        tx_buffer: 8192
      sfe:
        interfaces: [ens2f1]
        rx_buffer: 8192
        tx_buffer: 8192
      sbe:
        interfaces: [ens1f0]
        rx_buffer: 8192
        tx_buffer: 8192
  computev1:
    style: physical
    role: compute
    enabled: True
    os: ubuntu2004
    uuids:
#      - 00000000-0000-0000-0000-0CC47AFE2E04 ###- moved to dev -###
#      - 00000000-0000-0000-0000-0CC47AFE3030
      - 00000000-0000-0000-0000-0CC47AFE2E80
      - 00000000-0000-0000-0000-0CC47AFE2E50
      - 00000000-0000-0000-0000-0CC47AFE2EA4
      - 00000000-0000-0000-0000-0CC47AFE302C
      - 00000000-0000-0000-0000-0CC47AFE2E44
      - 00000000-0000-0000-0000-0CC47AFE2FA0
      - 00000000-0000-0000-0000-0CC47AFE2E2C
      - 00000000-0000-0000-0000-0CC47AFE2CEC
      - 00000000-0000-0000-0000-0CC47AFE2EB0
      - 00000000-0000-0000-0000-0CC47AFE2E18
    interface: enp97s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: Micron_9200_MTFDHAL1T6TCU
    networks:
      management:
        interfaces: [enp97s0f0]
        rx_buffer: 8192
        tx_buffer: 8192
      sfe:
        interfaces: [enp113s0f0]
        rx_buffer: 8192
        tx_buffer: 8192
      public:
        interfaces: [enp97s0f1]
        rx_buffer: 8192
        tx_buffer: 8192
      private:
        interfaces: [enp113s0f1]
        rx_buffer: 8192
        tx_buffer: 8192
    initial_cpu_allocation_ratio: 3.2
    initial_ram_allocation_ratio: 1.5
  computev2:
    style: physical
    role: compute
    enabled: True
    os: ubuntu2004
    uuids:
#      - 00000000-0000-0000-0000-0CC47AFE2CD8 ###- ipmi card not recognized -###
      - 00000000-0000-0000-0000-0CC47AFE3010
      - 00000000-0000-0000-0000-0CC47AFE2D10
      - 00000000-0000-0000-0000-0CC47AFE2FB8
      - 00000000-0000-0000-0000-0CC47AFE2FEC
      - 00000000-0000-0000-0000-0CC47AFE2E54
      - 00000000-0000-0000-0000-0CC47AFE2E88
      - 00000000-0000-0000-0000-0CC47AFE2E84
      - 00000000-0000-0000-0000-0CC47AFE3018
      - 00000000-0000-0000-0000-0CC47AFE2E8C
      - 00000000-0000-0000-0000-0CC47AFE2FA8
    interface: enp97s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: Micron_9200_MTFDHAL1T6TCU
    networks:
      management:
        interfaces: [enp97s0f0]
        rx_buffer: 8192
        tx_buffer: 8192
      sfe:
        interfaces: [enp113s0f0]
        rx_buffer: 8192
        tx_buffer: 8192
      public:
        interfaces: [enp97s0f1]
        rx_buffer: 8192
        tx_buffer: 8192
      private:
        interfaces: [enp113s0f1]
        rx_buffer: 8192
        tx_buffer: 8192
    initial_cpu_allocation_ratio: 3.2
    initial_ram_allocation_ratio: 1.5
  computev3:
    style: physical
    role: compute
    enabled: False
    os: ubuntu2004
    uuids:
      - 00000000-0000-0000-0000-AC1F6BC44096
      - 00000000-0000-0000-0000-AC1F6BC4419A
      - 00000000-0000-0000-0000-AC1F6BC44182
      - 00000000-0000-0000-0000-AC1F6BC4424A
      - 00000000-0000-0000-0000-AC1F6BC44246
      - 00000000-0000-0000-0000-AC1F6BC4425A
      - 00000000-0000-0000-0000-AC1F6BC441AA
      - 00000000-0000-0000-0000-AC1F6BC44186
      - 00000000-0000-0000-0000-AC1F6BC4425E
      - 00000000-0000-0000-0000-AC1F6BC4426A
      - 00000000-0000-0000-0000-AC1F6BC440B6
      - 00000000-0000-0000-0000-AC1F6BC440AA
    interface: enp129s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: INTEL SSDPE2KX010T8
    networks:
      management:
        interfaces: [enp129s0f0]
        rx_buffer: 4096
        tx_buffer: 4096
      sfe:
        interfaces: [enp129s0f1]
        rx_buffer: 4096
        tx_buffer: 4096
      public:
        interfaces: [enp193s0f0]
        rx_buffer: 4096
        tx_buffer: 4096
      private:
        interfaces: [enp193s0f1]
        rx_buffer: 4096
        tx_buffer: 4096
    initial_cpu_allocation_ratio: 1.6
    initial_ram_allocation_ratio: 1.5
  computev4:
    style: physical
    role: compute
    enabled: False
    os: ubuntu2004
    uuids:
      - 00000000-0000-0000-0000-3CECEF4A6440
      - 00000000-0000-0000-0000-3CECEF4A2064
      - 00000000-0000-0000-0000-3CECEF4A1564
      - 00000000-0000-0000-0000-3CECEF4A6328
      - 00000000-0000-0000-0000-3CECEF4A24D8
      - 00000000-0000-0000-0000-3CECEF4A6464
      - 00000000-0000-0000-0000-3CECEF4A2684
      - 00000000-0000-0000-0000-3CECEF4A6434
      - 00000000-0000-0000-0000-3CECEF4A644C
      - 00000000-0000-0000-0000-3CECEF4A6420
      - 00000000-0000-0000-0000-3CECEF4A6348
      - 00000000-0000-0000-0000-3CECEF4A20BC
    interface: enp129s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: INTEL SSDPE2KX010T8
    networks:
      management:
        interfaces: [enp129s0f0]
        rx_buffer: 4096
        tx_buffer: 4096
      sfe:
        interfaces: [enp161s0f1]
        rx_buffer: 4096
        tx_buffer: 4096
      public:
        interfaces: [enp161s0f0]
        rx_buffer: 4096
        tx_buffer: 4096
      private:
        interfaces: [enp129s0f1]
        rx_buffer: 4096
        tx_buffer: 4096
    initial_cpu_allocation_ratio: 1.6
    initial_ram_allocation_ratio: 1.5
  containerv1:
    style: physical
    role: container
    enabled: False
    os: ubuntu2004
    uuids:
      - 00000000-0000-0000-0000-0CC47AF98E10
    interface: ens2f0np0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: INTEL SSDSC2BA40
    networks:
      management:
        interfaces: [ens2f0np0]
        rx_buffer: 4096
        tx_buffer: 2048
      sfe:
        interfaces: [ens2f1np1]
        rx_buffer: 4096
        tx_buffer: 2048
      public:
        interfaces: [ens2f3np3]
        rx_buffer: 4096
        tx_buffer: 2048
      private:
        interfaces: [ens2f2np2]
        rx_buffer: 4096
        tx_buffer: 2048
  gpu:
    style: physical
    role: gpu
    enabled: False
    os: ubuntu2004
    uuids:
      - 00000000-0000-0000-0000-3CECEF11D836
      - 00000000-0000-0000-0000-3CECEF11D832
      - 00000000-0000-0000-0000-3CECEF11D80E
      - 00000000-0000-0000-0000-3CECEF1166F2
      - 00000000-0000-0000-0000-3CECEF4A3AD8
    interface: enp161s0f0
    proxy: pull_from_mine
    root_password_crypted: $6$sSXsfvsKhwy$RrINorhH4lNeNdNbi/vHqCAApM8ID9Lhvmzs6OQMO4791igXZIrhWg6Kyi7XPRGhIZOgGUdCx4prarhaV62id0
    ntp_server: time-d-g.nist.gov
    disk: INTEL SSDPE2KX010T8
    networks:
      management:
        interfaces: [enp161s0f0]
        rx_buffer: 4096
        tx_buffer: 4096
      sfe:
        interfaces: [enp161s0f1]
        rx_buffer: 4096
        tx_buffer: 4096
      public:
        interfaces: [enp193s0f0]
        rx_buffer: 4096
        tx_buffer: 4096
      private:
        interfaces: [enp193s0f1]
        rx_buffer: 4096
        tx_buffer: 4096
    initial_cpu_allocation_ratio: 1.6
    initial_ram_allocation_ratio: 1.5
  cache:
    style: virtual
    enabled: False
    count: 1
    ram: 8192000
    cpu: 2
    os: ubuntu2004
    disk: 512G
    networks:
      management:
        interfaces: [ens3]
  cephmon:
    style: virtual
    enabled: False
    count: 3
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
      sfe:
        interfaces: [ens4]
  mds:
    style: virtual
    enabled: True
    count: 3
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
      sfe:
        interfaces: [ens4]
  haproxy:
    style: virtual
    enabled: False
    count: 3
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  antora:
    style: virtual
    enabled: False
    count: 1
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 32G
    networks:
      management:
        interfaces: [ens3]
  mysql:
    style: virtual
    enabled: True
    count: 3
    ram: 32768000
    cpu: 8
    os: ubuntu2004
    disk: 128G
    networks:
      management:
        interfaces: [ens3]
  rabbitmq:
    style: virtual
    enabled: True
    count: 3
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  memcached:
    style: virtual
    enabled: True
    count: 3
    ram: 16384000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  keystone:
    style: virtual
    enabled: True
    count: 3
    ram: 16384000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  glance:
    style: virtual
    enabled: True
    count: 3
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
      sfe:
        interfaces: [ens4]
  nova:
    style: virtual
    enabled: True
    count: 10
    ram: 16384000
    cpu: 8
    os: ubuntu2004
    disk: 128G
    networks:
      management:
        interfaces: [ens3]
  neutron:
    style: virtual
    enabled: True
    count: 6
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  horizon:
    style: virtual
    enabled: False
    count: 5
    ram: 16384000
    cpu: 8
    os: ubuntu2004
    disk: 128G
    networks:
      management:
        interfaces: [ens3]
  heat:
    style: virtual
    enabled: True
    count: 4
    ram: 16384000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  cinder:
    style: virtual
    enabled: True
    count: 3
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  volume:
    style: virtual
    enabled: True
    count: 3
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
      sfe:
        interfaces: [ens4]
  designate:
    style: virtual
    enabled: True
    count: 3
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  bind:
    style: virtual
    enabled: True
    count: 3
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  swift:
    style: virtual
    enabled: True
    count: 3
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
      sfe:
        interfaces: [ens4]
  zun:
    style: virtual
    enabled: True
    count: 2
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  placement:
    style: virtual
    enabled: True
    count: 6
    ram: 8192000
    cpu: 2
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  graylog:
    style: virtual
    enabled: False
    count: 1
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 512G
    networks:
      management:
        interfaces: [ens3]
  network:
    style: virtual
    enabled: False
    count: 5
    ram: 8192000
    cpu: 4
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
      private:
        interfaces: [ens4]
      public:
        interfaces: [ens5]
  ovsdb:
    style: virtual
    enabled: True
    count: 1
    ram: 16384000
    cpu: 6
    os: ubuntu2004
    disk: 128G
    networks:
      management:
        interfaces: [ens3]
  barbican:
    style: virtual
    enabled: False
    count: 2
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  magnum:
    style: virtual
    enabled: False
    count: 2
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  sahara:
    style: virtual
    enabled: False
    count: 2
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  manila:
    style: virtual
    enabled: False
    count: 3
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  share:
    style: virtual
    enabled: False
    count: 3
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
      sfe:
        interfaces: [ens4]
  etcd:
    style: virtual
    enabled: True
    count: 3
    ram: 4096000
    cpu: 2
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  guacamole:
    style: virtual
    enabled: False
    count: 1
    ram: 8192000
    cpu: 2
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]
  webssh2:
    style: virtual
    enabled: False
    count: 1
    ram: 8192000
    cpu: 2
    os: ubuntu2004
    disk: 64G
    networks:
      management:
        interfaces: [ens3]